"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// having weak reference to styles prevents garbage collection
// and "losing" styles when the next test starts
var stylesCache = new Map();
var copyStyles = function (component) {
    // need to find same component when component is recompiled
    // by the JSX preprocessor. Thus have to use something else,
    // like component name
    var hash = component.type.name;
    var styles = document.querySelectorAll('head style');
    if (styles.length) {
        console.log('injected %d styles', styles.length);
        stylesCache.set(hash, styles);
    }
    else {
        console.log('No styles injected for this component, checking cache');
        if (stylesCache.has(hash)) {
            styles = stylesCache.get(hash);
        }
        else {
            styles = null;
        }
    }
    if (!styles) {
        return;
    }
    var parentDocument = window.parent.document;
    var projectName = Cypress.config('projectName');
    var appIframeId = "Your App: '" + projectName + "'";
    var appIframe = parentDocument.getElementById(appIframeId);
    var head = appIframe.contentDocument.querySelector('head');
    styles.forEach(function (style) {
        head.appendChild(style);
    });
};
/* eslint-env mocha */
exports.mount = function (jsx) {
    // include React and ReactDOM from CDN to force DOM to register all DOM event listeners
    // otherwise the component will NOT be able to dispatch any events
    // when it runs the second time
    // https://github.com/bahmutov/cypress-react-unit-test/issues/3
    var html = "<body>\n    <div id=\"app\"></div>\n    <script src=\"https://cdnjs.cloudflare.com/ajax/libs/react/16.2.0/umd/react.development.js\"></script>\n    <script src=\"https://cdnjs.cloudflare.com/ajax/libs/react-dom/16.2.0/umd/react-dom.development.js\"></script>\n  </body>";
    var document = cy.state('document');
    document.write(html);
    document.close();
    cy.window({ log: false })
        .its('ReactDOM.render')
        .then(function (render) {
        Cypress._component = render(jsx, document.getElementById('app'));
        Cypress.component = function () {
            return cy.then(function () { return Cypress._component; });
        };
    });
    copyStyles(jsx);
};
